@@ -247,10 +247,14 @@ void SessionPrivate::responseReceived(const Response &response)
             setState(Session::NotAuthenticated);
 
             Response simplified = response;
+            supportsStartTls = std::any_of(response.responseCode.cbegin(), response.responseCode.cend(),
+                                           [](const Response::Part &part) {
+                                                return part.type() == Response::Part::String
+                                                        && part.toString() == "STARTTLS";
+                                           });
             simplified.content.removeFirst(); // Strip the tag
             simplified.content.removeFirst(); // Strip the code
             greeting = simplified.toString().trimmed(); // Save the server greeting
-
             startNext();
         } else if (code == "PREAUTH") {
             setState(Session::Authenticated);
@@ -362,10 +366,7 @@ void SessionPrivate::socketConnected()
     if (!queue.isEmpty()) {
         KIMAP::LoginJob *login = qobject_cast<KIMAP::LoginJob *>(queue.first());
         if (login) {
-            willUseSsl = (login->encryptionMode() == KIMAP::LoginJob::SslV2) ||
-                         (login->encryptionMode() == KIMAP::LoginJob::SslV3) ||
-                         (login->encryptionMode() == KIMAP::LoginJob::SslV3_1) ||
-                         (login->encryptionMode() == KIMAP::LoginJob::AnySslVersion);
+            willUseSsl = (login->encryptionMode() == KIMAP::LoginJob::SSLorTLS);
 
             userName = login->userName();
         }
