@@ -48,7 +48,7 @@ class KIMAP_EXPORT SessionPrivate : public QObject
 
 public:
     explicit SessionPrivate(Session *session);
-    virtual ~SessionPrivate();
+    ~SessionPrivate() override;
 
     void addJob(Job *job);
     QByteArray sendCommand(const QByteArray &command, const QByteArray &args = QByteArray());
@@ -60,6 +60,10 @@ public:
     void setSocketTimeout(int ms);
     int socketTimeout() const;
 
+    bool canStartTls() const {
+        return q->state() == Session::NotAuthenticated && supportsStartTls;
+    }
+
 Q_SIGNALS:
     void encryptionNegotiationResult(bool);
 
@@ -116,6 +120,8 @@ private:
 
     int socketTimerInterval = 0;
     QTimer socketTimer;
+
+    bool supportsStartTls = false;
 };
 
 }
